Package 'rolleda'

Title: Rolling Exploratory Data Analysis
Description: Exploratory data analysis of rolling statistics for time-series data. The 'rolleda' package explores the rolling statistics of the 'roll' package in a 'Shiny' web application that is launched with the roll_eda() function.
Authors: Jason Foster [aut, cre]
Maintainer: Jason Foster <[email protected]>
License: GPL (>= 2)
Version: 1.0.0
Built: 2026-06-05 02:51:05 UTC
Source: https://github.com/jasonjfoster/rolleda

Help Index


Rolling Exploratory Data Analysis

Description

Exploratory data analysis of rolling statistics for time-series data. The 'rolleda' package explores the rolling statistics of the 'roll' package in a 'Shiny' web application that is launched with the roll_eda() function.

Details

rolleda is a package that provides exploratory data analysis of rolling statistics for time-series data.

Author(s)

Jason Foster [aut, cre]


Rolling Exploratory Data Analysis

Description

A web application for rolling exploratory data analysis of time-series data.

Usage

roll_eda(...)

Arguments

...

Additional arguments passed to shiny::shinyApp.

Value

A Shiny app object for rolling exploratory data analysis of time-series data.

Examples

## Not run: 
# rolling exploratory data analysis
roll_eda()

## End(Not run)