| Title: | Rolling Exploratory Data Analysis |
|---|---|
| Description: | Exploratory data analysis of rolling statistics for time-series data. The 'rolleda' package explores the rolling statistics of the 'roll' package in a 'Shiny' web application that is launched with the roll_eda() function. |
| Authors: | Jason Foster [aut, cre] |
| Maintainer: | Jason Foster <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.0.0 |
| Built: | 2026-06-05 02:51:05 UTC |
| Source: | https://github.com/jasonjfoster/rolleda |
Exploratory data analysis of rolling statistics for time-series data. The 'rolleda' package explores the rolling statistics of the 'roll' package in a 'Shiny' web application that is launched with the roll_eda() function.
rolleda is a package that provides exploratory data analysis of rolling statistics for time-series data.
Jason Foster [aut, cre]
A web application for rolling exploratory data analysis of time-series data.
roll_eda(...)roll_eda(...)
... |
Additional arguments passed to |
A Shiny app object for rolling exploratory data analysis of time-series data.
## Not run: # rolling exploratory data analysis roll_eda() ## End(Not run)## Not run: # rolling exploratory data analysis roll_eda() ## End(Not run)